| CorrAnalysis | R Documentation |
Computes the correlation matrix along with corresponding p-values and visualizes the correlations using a heatmap.
CorrAnalysis(data)
data |
A numeric data frame or matrix containing variables (e.g., one dependent variable y and multiple independent variables x). |
A list containing:
correlation_matrix: Numeric correlation matrix
p_value_matrix: Formatted p-value matrix (character)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.